package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.AmsFeign;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author luobang
 * @create 2021-09-17 14:10
 */
@RestController
@RequestMapping("${api.version}/ams")
public class AMScontroller{

    @Autowired
    AmsFeign amsFeign;

    @ApiOperation(value="查询运输预约")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(79)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllPurPlan")
    public Map<String, Object> getAllPurPlan(@RequestBody(required = false) Map<String, Object> mapValue,
                                       Integer apiId,
                                       Integer pageNum,
                                       Integer pageSize,
                                       Integer status,String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getAllPurPlan(mapValue, apiId, pageNum, pageSize, status, con);
    }

    @ApiOperation(value = "通过Id查询请车作业")
    @PostMapping("/getPurPlanById/{planId}")
    public Map<String, Object> getPurPlanById(@PathVariable("planId") Integer planId) {
        return amsFeign.getPurPlanById(planId);
    }

    @ApiOperation(value = "新增运输计划 状态：0")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amstruckPurplan", value = "运输计划实绩对象", required = false, dataType = "AmstruckPurplan"),
    })
    @PostMapping("/addPurPlan")
    public Map<String, Object> addPurPlan(@RequestBody Map<String, Object> map) {
        return amsFeign.addPurPlan(map);
    }

    @ApiOperation(value="修改运输计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amstruckPurplan", value = "请车作业实绩对象", required = false, dataType = "AmstruckPurplan"),
    })
    @PostMapping("/updatePurPlan")
    public Map<String, Object> updatePurPlan(@RequestBody Map<String, Object> amstruckPurplan){
        return amsFeign.updatePurPlan(amstruckPurplan);
    }
    
    @ApiOperation(value = "下发运输计划 状态：1")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "运输计划Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/sendPurPlan/{planId}")
    public Map<String, Object> sendPurPlan(@PathVariable("planId") Integer planId) {
        return amsFeign.sendPurPlan(planId);
    }

    @ApiOperation(value = "接收运输计划 状态：2")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "运输计划Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/receptionPurPlan/{planId}")
    public Map<String, Object> receptionPurPlan(@PathVariable("planId") Integer planId) {
        return amsFeign.receptionPurPlan(planId);
    }

    @ApiOperation(value = "逻辑删除运输计划 状态：3")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "运输计划Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/deletePurPlan/{planId}")
    public Map<String, Object> deletePurPlan(@PathVariable("planId") Integer planId) {
        return amsFeign.deletePurPlan(planId);
    }

    //**************************************************************************************
    @ApiOperation(value = "查询要分派的计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(82)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getDecomposedPlan")
    public Map<String, Object> getDecomposedPlan(@RequestBody(required = false) Map<String, Object> mapValue,
                                           Integer apiId,
                                           Integer pageNum,
                                           Integer pageSize,
                                           Integer planId,
                                           Integer status, String con) {
        return amsFeign.getDecomposedPlan(mapValue == null? new HashMap<>() : mapValue, apiId, pageNum, pageSize, planId, status, con);
    }


    /**
     * 违约规则
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getBreachList")
    @ApiOperation(value = "展示违约列表")
    public Map<String, Object> getBreachList(@RequestBody(required = false) Map<String, Object> mapValue,
                                       Integer pageNum,
                                       Integer pageSize,
                                       Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getBreachList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addContractBreach")
    @ApiOperation(value = "新增违约规则")
    Map<String, Object> addContractBreach(@RequestBody Map<String, Object> amsContractBreach) {
        return amsFeign.addContractBreach(amsContractBreach);
    }

    @PostMapping("deleteContractBreach/{breachId}")
    @ApiOperation(value = "逻辑删除违约规则")
    Map<String, Object> deleteContractBreach(@PathVariable("breachId") BigDecimal breachId) {
        return amsFeign.deleteContractBreach(breachId);
    }

    @PostMapping("updateContractBreach")
    @ApiOperation(value = "修改违约规则")
    Map<String, Object> updateContractBreach(@RequestBody Map<String, Object> amsContractBreach) {
        return amsFeign.updateContractBreach(amsContractBreach);
    }

    @PostMapping("selectBreachToUpdate/{breachId}")
    @ApiOperation(value = "查询违约规则")
    Map<String, Object> selectBreachToUpdate(@PathVariable("breachId") BigDecimal breachId) {
        return amsFeign.selectBreachToUpdate(breachId);
    }


    /**
     * 港口装卸单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getLoadUnloadPriceList")
    @ApiOperation(value = "展示港口装卸单价列表")
    public Map<String, Object> getLoadUnloadPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                Integer pageNum,
                                                Integer pageSize,
                                                Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getLoadUnloadPriceList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addLoadUnloadPrice")
    @ApiOperation(value = "新增港口装卸单价")
    Map<String, Object> addLoadUnloadPrice(@RequestBody Map<String, Object> amsContractOtherPrice) {
        return amsFeign.addLoadUnloadPrice(amsContractOtherPrice);
    }

    @PostMapping("deleteLoadUnloadPrice/{priceId}")
    @ApiOperation(value = "逻辑删除港口装卸单价")
    Map<String, Object> deleteLoadUnloadPrice(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.deleteLoadUnloadPrice(priceId);
    }

    @PostMapping("updateLoadUnloadPrice")
    @ApiOperation(value = "修改港口装卸单价")
    Map<String, Object> updateLoadUnloadPrice(@RequestBody Map<String, Object> amsContractOtherPrice) {
        return amsFeign.updateLoadUnloadPrice(amsContractOtherPrice);
    }

    @PostMapping("selectLoadUnloadPriceToUpdate/{priceId}")
    @ApiOperation(value = "查询港口装卸单价")
    Map<String, Object> selectLoadUnloadPriceToUpdate(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.selectLoadUnloadPriceToUpdate(priceId);
    }


    /**
     * 火运单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getTrainPriceList")
    @ApiOperation(value = "展示火运单价列表")
    public Map<String, Object> getTrainPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                           Integer pageNum,
                                           Integer pageSize,
                                           Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getTrainPriceList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addTrainPrice")
    @ApiOperation(value = "新增火运单价")
    Map<String, Object> addTrainPrice(@RequestBody Map<String, Object> amsContractTrainPrice) {
        return amsFeign.addTrainPrice(amsContractTrainPrice);
    }

    @PostMapping("deleteTrainPrice/{priceId}")
    @ApiOperation(value = "逻辑删除火运单价")
    Map<String, Object> deleteTrainPrice(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.deleteTrainPrice(priceId);
    }

    @PostMapping("updateTrainPrice")
    @ApiOperation(value = "修改火运单价")
    Map<String, Object> updateTrainPrice(@RequestBody Map<String, Object> amsContractTrainPrice) {
        return amsFeign.updateTrainPrice(amsContractTrainPrice);
    }

    @PostMapping("selectTrainPriceToUpdate/{priceId}")
    @ApiOperation(value = "通过id查询火运单价")
    Map<String, Object> selectTrainPriceToUpdate(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.selectTrainPriceToUpdate(priceId);
    }

    /**
     * 运费单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getShipPriceList")
    @ApiOperation(value = "展示水运单价列表")
    public Map<String, Object> getShipPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getShipPriceList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addShipPrice")
    @ApiOperation(value = "新增水运单价")
    Map<String, Object> addShipPrice(@RequestBody Map<String, Object> amsContractTransportPrice) {
        return amsFeign.addShipPrice(amsContractTransportPrice);
    }

    @PostMapping("deleteShipPrice/{priceId}")
    @ApiOperation(value = "逻辑删除运费单价")
    Map<String, Object> deleteShipPrice(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.deleteShipPrice(priceId);
    }

    @PostMapping("updateShipPrice")
    @ApiOperation(value = "修改水运单价")
    Map<String, Object> updateShipPrice(@RequestBody Map<String, Object> amsContractTransportPrice) {
        return amsFeign.updateShipPrice(amsContractTransportPrice);
    }

    @PostMapping("selectPriceToUpdate/{priceId}")
    @ApiOperation(value = "通过id查询运费单价")
    Map<String, Object> selectPriceToUpdate(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.selectPriceToUpdate(priceId);
    }

    @PostMapping("getTruckPriceList")
    @ApiOperation(value = "展示汽运单价列表")
    public Map<String, Object> getTruckPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                           Integer pageNum,
                                           Integer pageSize,
                                           Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getTruckPriceList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addAmsContractTransportPrice")
    @ApiOperation(value = "新增汽运单价")
    Map<String, Object> addAmsContractTransportPrice(@RequestBody Map<String, Object> amsContractTransportPrice) {
        return amsFeign.addAmsContractTransportPrice(amsContractTransportPrice);
    }

    @PostMapping("updateAmsContractTransportPrice")
    @ApiOperation(value = "修改汽运单价")
    Map<String, Object> updateAmsContractTransportPrice(@RequestBody Map<String, Object> amsContractTransportPrice) {
        return amsFeign.updateAmsContractTransportPrice(amsContractTransportPrice);
    }


    @PostMapping("getPurchaseOrderList")
    @ApiOperation(value = "展示采购订单列表")
    public Map<String, Object> getPurchaseOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                              Integer pageNum,
                                              Integer pageSize,
                                              Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getPurchaseOrderList(mapValue, pageNum, pageSize, apiId);
    }

    /**
     * 下拉框
     * @return
     */
    @GetMapping("getAddressDeliveryAddress")
    @ApiOperation(value = "得到地址下拉")
    public Map<String, Object> getAddressDeliveryAddress(){
        return amsFeign.getAddressDeliveryAddress();
    }

    @GetMapping("getShipperId")
    @ApiOperation(value = "得到托运人下拉")
    public Map<String, Object> getShipperId(){
        return amsFeign.getShipperId();
    }

    @GetMapping("getCarrierId")
    @ApiOperation(value = "得到承运商下拉")
    public Map<String, Object> getCarrierId(){
        return amsFeign.getCarrierId();
    }

    @GetMapping("getCapacityId")
    @ApiOperation(value = "获取船id下拉列表")
    public Map<String, Object> getCapacityId(){
        return amsFeign.getCapacityId();
    }

    @GetMapping("getMaterialId")
    @ApiOperation(value = "得到物资下拉")
    public Map<String, Object> getMaterialId(){
        return amsFeign.getMaterialId();
    }

    @GetMapping("getTruckCapacityId")
    @ApiOperation(value = "得到车牌号下拉")
    public Map<String, Object> getTruckCapacityId(){
        return amsFeign.getTruckCapacityId();
    }

    @GetMapping("getLineId")
    @ApiOperation(value = "获取运输线路下拉列表")
    public Map<String, Object> getLineId(){
        return amsFeign.getLineId();
    }
// ----------------------------------销售合同-------------------------------------------
    /**
     * 查询汽运单价信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("/amscontracttransportprices")
    @ApiOperation(value = "查询汽运单价信息")
    public Map<String, Object> amscontracttransportprices(@RequestBody(required = false) Map<String, Object> mapValue,
                                       Integer pageNum,
                                       Integer pageSize,
                                       Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.amscontracttransportprices(mapValue, pageNum, pageSize, apiId);
    }

    /**
     * 新增汽运单价
     * @param mapVal
     * @return
     */
    @PostMapping("addAmsContractTransportUnitPrice")
    @ApiOperation(value = "新增汽运单价")
    Map<String, Object> addAmsContractTransportUnitPrice(@RequestBody Map<String, Object> mapVal) {
        return amsFeign.addAmsContractTransportUnitPrice(mapVal);
    }
    @PostMapping("deleteAmsContractTransportPrice")
    @ApiOperation(value = "通过主键id删除汽运单价")
    Map<String, Object> deleteAmsContractTransportPrice(BigDecimal priceId) {
        return amsFeign.deleteAmsContractTransportPrice(priceId);
    }

    /**
     * 通过主键修改汽运单价
     */
    @PostMapping("updateAmsContractTransportUnitPrice")
    @ApiOperation(value = "通过主键id修改汽运单价")
    Map<String, Object> updateAmsContractTransportUnitPrice(@RequestBody(required = false) Map<String, Object> mapVal) {
        return amsFeign.updateAmsContractTransportUnitPrice(mapVal);
    }
    /**
     * 通过主键修改汽运单价
     */
    @PostMapping("batchUpdateTransportPriceByOilPrice")
    @ApiOperation(value = "油价联动导致运价变动，批量修改运价")
    Map<String, Object> batchUpdateTransportPriceByOilPrice(@RequestBody(required = false) Map<String, Object> mapVal) {
        return amsFeign.batchUpdateTransportPriceByOilPrice(mapVal);
    }
    @GetMapping("getLineNo")
    @ApiOperation(value = "得到线路编号下拉")
    public Map<String, Object> getLineNo(){
        return amsFeign.getLineNo();
    }
    @GetMapping("getCapacityNumber")
    @ApiOperation(value = "得到运力编号下拉")
    public Map<String, Object> getCapacityNumber(){
        return amsFeign.getCapacityNumber();
    }
    @GetMapping("getDeliveryAddress")
    @ApiOperation(value = "得到收货地址下拉")
    public Map<String, Object> getDeliveryAddress(){
        return amsFeign.getDeliveryAddress();
    }
    @PostMapping("/addAmsDispatchSaleOrder")
    Map<String, Object> addAmsDispatchSaleOrder(@RequestBody(required = false) Map<String, Object> mapVal) {
        return amsFeign.addAmsDispatchSaleOrder(mapVal);
    }
    @GetMapping("getCarrierName")
    @ApiOperation(value = "得到承运商名称")
    public Map<String, Object> getCarrierName(){
        return amsFeign.getCarrierName();
    }
    @PostMapping("getSaleOrderInfo")
    @ApiOperation(value = "查询汽运单价信息")
    public Map<String, Object> getSaleOrderInfo(@RequestBody(required = false) Map<String, Object> mapValue,
                                                    Integer pageNum,
                                                    Integer pageSize,
                                                    Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSaleOrderInfo(mapValue, pageNum, pageSize, apiId);
    }
    @PostMapping("getAmsSaleOrderApproved")
    @ApiOperation(value = "查询汽运单价信息")
    public Map<String, Object> getAmsSaleOrderApproved(@RequestBody(required = false) Map<String, Object> mapValue,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getAmsSaleOrderApproved(mapValue, pageNum, pageSize, apiId);
    }
    @PostMapping("getSaleOrderDetail")
    @ApiOperation(value = "查询汽运单价信息")
    public Map<String, Object> getSaleOrderDetail(@RequestBody(required = false) Map<String, Object> mapValue,
                                                 Integer pageNum,
                                                 Integer pageSize,
                                                 Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSaleOrderDetail(mapValue, pageNum, pageSize, apiId);
    }
    @PostMapping("uploadSaleOrder/{saleOrderId}")
    Map<String, Object> uploadSaleOrder(@PathVariable("saleOrderId") BigDecimal saleOrderId) {
        return amsFeign.uploadSaleOrder(saleOrderId);
    }
    @PostMapping("/addAmsSaleOrder")
    Map<String, Object> addAmsSaleOrder(@RequestBody(required = false) Map<String, Object> mapVal) {
        return amsFeign.addAmsSaleOrder(mapVal);
    }
    @PostMapping("getAmsSaleOrderBySaleOrderId/{saleOrderId}")
    Map<String, Object> getAmsSaleOrderBySaleOrderId(@PathVariable("saleOrderId") BigDecimal saleOrderId) {
        return amsFeign.getAmsSaleOrderBySaleOrderId(saleOrderId);
    }
    @PostMapping("/updateAmsSaleOrder")
    Map<String, Object> updateAmsSaleOrder(@RequestBody(required = false) Map<String, Object> mapVal) {
        return amsFeign.updateAmsSaleOrder(mapVal);
    }
    @PostMapping("deleteAmsSaleOrderBySaleOrderId/{saleOrderId}")
    Map<String, Object> deleteAmsSaleOrderBySaleOrderId(@PathVariable("saleOrderId") BigDecimal saleOrderId) {
        return amsFeign.deleteAmsSaleOrderBySaleOrderId(saleOrderId);
    }
    @PostMapping("getSaleOrderUpdateLog")
    @ApiOperation(value = "查询汽运单价信息")
    public Map<String, Object> getSaleOrderUpdateLog(@RequestBody(required = false) Map<String, Object> mapValue,
                                            Integer pageNum,
                                            Integer pageSize,
                                            Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSaleOrderUpdateLog(mapValue, pageNum, pageSize, apiId);
    }
    @GetMapping("getShipperName")
    @ApiOperation(value = "得到发货单位下拉")
    public Map<String, Object> getShipperName(){
        return amsFeign.getShipperName();
    }
    @GetMapping("getConsigneeCompanyName")
    @ApiOperation(value = "得到收货单位下拉")
    public Map<String, Object> getConsigneeCompanyName(){
        return amsFeign.getConsigneeCompanyName();
    }
    @PostMapping("addAmsSaleOrderMaterial")
    Map<String, Object> addAmsSaleOrderMaterial(@RequestBody(required = false) Map<String,Object> map) {
        return amsFeign.addAmsSaleOrderMaterial(map);
    }
    @PostMapping("getAmsSaleOrderMaterialBySaleOrderMaterialId/{saleOrderMaterialId}")
    Map<String, Object> getAmsSaleOrderMaterialBySaleOrderMaterialId(@PathVariable("saleOrderMaterialId") BigDecimal saleOrderMaterialId) {
        return amsFeign.getAmsSaleOrderMaterialBySaleOrderMaterialId(saleOrderMaterialId);
    }
    @PostMapping("deleteAmsSaleOrderMaterialBySaleOrderMaterialId")
    Map<String, Object> deleteAmsSaleOrderMaterialBySaleOrderMaterialId(BigDecimal saleOrderMaterialId) {
        return amsFeign.deleteAmsSaleOrderMaterialBySaleOrderMaterialId(saleOrderMaterialId);
    }
    @PostMapping("getAddress/{saleOrderMaterialId}")
    Map<String, Object> getAddress(BigDecimal saleOrderMaterialId) {
        return amsFeign.getAddress(saleOrderMaterialId);
    }
    @PostMapping("updateAddress")
    Map<String, Object> updateAddress(@RequestBody(required = false)Map<String,Object> map) {
        return amsFeign.updateAddress(map);
    }
    @PostMapping("getSalePlanInfo")
    @ApiOperation(value = "查询汽运单价信息")
    public Map<String, Object> getSalePlanInfo(@RequestBody(required = false) Map<String, Object> mapValue,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSalePlanInfo(mapValue, pageNum, pageSize, apiId);
    }
    @PostMapping("addAmsSalePlan")
    Map<String, Object> addAmsSalePlan(@RequestBody(required = false)Map<String,Object> map) {
        return amsFeign.addAmsSalePlan(map);
    }
    @PostMapping("getAmsSalePlanByPlanId/{planId}")
    Map<String, Object> getAmsSalePlanByPlanId(BigDecimal planId) {
        return amsFeign.getAmsSalePlanByPlanId(planId);
    }
    @PostMapping("upadteAmsSalePlanByPlanId")
    Map<String, Object> upadteAmsSalePlanByPlanId(@RequestBody(required = false)Map<String,Object> map) {
        return amsFeign.upadteAmsSalePlanByPlanId(map);
    }
    @PostMapping("deleteAmsSalePlanByPlanId")
    Map<String, Object> deleteAmsSalePlanByPlanId(@RequestParam BigDecimal planId) {
        return amsFeign.deleteAmsSalePlanByPlanId(planId);
    }
    @GetMapping("getMaterialName")
    @ApiOperation(value = "得到收货单位下拉")
    public Map<String, Object> getMaterialName(){
        return amsFeign.getMaterialName();
    }
    @GetMapping("getAreaName")
    @ApiOperation(value = "得到收货单位下拉")
    public Map<String, Object> getAreaName(){
        return amsFeign.getAreaName();
    }
    //************************************内转物流***************************************************
    @PostMapping("getAmsContractTransportPriceForConverted")
    @ApiOperation(value = "内转物流查询汽运单价信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(205)", value = "表头", required = false, dataType = "Interger")
    })
   public Map<String,Object> getAmsContractTransportPriceForConverted(@PathVariable("lineId")BigDecimal lineId,
                                         Integer apiId,
                                         Integer pageNum,
                                         Integer pageSize) {
        return amsFeign.getAmsContractTransportPriceForConverted(lineId, pageNum, pageSize, apiId);
    }
    /**
     * 下拉框显示线路
     */
    @ApiOperation(value="获取线路")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/getLineRoute")
    public Map<String,Object> getLineRoute(){
        return amsFeign.getLineRoute();
    }

    //销售订单-固定派单-公开派单-日计划


    //展示销售公司已审核销售订单的车序号列表
    @PostMapping("/getSaleOrderList")
    @ApiOperation(value = "查询汽运单价信息")
    public Map<String,Object> amsSaleOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.amsSaleOrderList(mapValue, pageNum, pageSize, apiId);
    }

    //固定派单：通过车序号查询收货地址，截取收货地址的区域，去资源管理中查询对应的承运商,将车序号与承运商绑定
    @PostMapping("/addFixedAmsDispatchSaleOrder")
    Map<String,Object> addFixedAmsDispatchSaleOrder(@RequestBody(required = false) List<Map<String,Object>> mapValue) {
        return amsFeign.addFixedAmsDispatchSaleOrder(mapValue);
    }

    //公开派单
    //查询未分派车辆的销售订单的车序号
    @PostMapping("/getAmsSaleOrderMaterial")
    @ApiOperation(value = "展示车序号列表")
    public Map<String,Object> getAmsSaleOrderMaterial(@RequestBody(required = false) Map<String, Object> mapValue,
                                                 Integer pageNum,
                                                 Integer pageSize,
                                                 Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getAmsSaleOrderMaterial(mapValue, pageNum, pageSize, apiId);
    }

    //新增公开派单
    @PostMapping("/addOpenAmsDispatchSaleOrder/{saleOrderMaterialId}")
    Map<String,Object> addOpenAmsDispatchSaleOrder(@PathVariable("saleOrderMaterialId") BigDecimal saleOrderId) {
        return amsFeign.addOpenAmsDispatchSaleOrder(saleOrderId);
    }

    //删除公开派单
    @PostMapping("/deleteAmsDispatchSaleOrder/{dispatchId}")
    Map<String,Object> deleteAmsDispatchSaleOrder(@PathVariable("dispatchId") BigDecimal saleOrderId) {
        return amsFeign.deleteAmsDispatchSaleOrder(saleOrderId);
    }

    //展示公开派单
    @PostMapping("/getOpenDispatchSaleOrder")
    @ApiOperation(value = "公开派单")
    public Map<String,Object> getOpenDispatchSaleOrder(@RequestBody(required = false) Map<String, Object> mapValue,
                                                  Integer pageNum,
                                                  Integer pageSize,
                                                  Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getOpenDispatchSaleOrder(mapValue, pageNum, pageSize, apiId);
    }

    //修改公开派单
    @PostMapping("/updateOpenDispatchSaleOrder")
    Map<String,Object> updateOpenDispatchSaleOrder(@RequestBody  Map<String, Object> mapVal) {
        return amsFeign.updateOpenDispatchSaleOrder(mapVal);
    }

    //焦炭、水渣日计划
    //新增
    @PostMapping("/addTruckRailDayPlan")
    public Map<String,Object> addTruckRailDayPlan(@RequestBody  Map<String, Object> mapVal) {
        return amsFeign.addTruckRailDayPlan(mapVal);
    }
    //删除
    @PostMapping("/deleteTruckRailDayPlan/{dayPlanId}")
    public Map<String,Object> deleteTruckRailDayPlan(@PathVariable("dayPlanId") BigDecimal dayPlanId) {
        return amsFeign.deleteTruckRailDayPlan(dayPlanId);
    }
    //修改
    @PostMapping("/updateTruckRailDayPlan")
    public Map<String,Object> updateTruckRailDayPlan(@RequestBody  Map<String, Object> mapVal) {
        return amsFeign.updateTruckRailDayPlan(mapVal);
    }
    //展示日计划
    @PostMapping("/getTruckRailDayPlanList")
    @ApiOperation(value = "焦炭日计划")
    public Map<String, Object> getTruckRailDayPlan(@RequestBody(required = false) Map<String, Object> mapValue,
                                             Integer pageNum,
                                             Integer pageSize,
                                             Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getTruckRailDayPlan(mapValue, pageNum, pageSize, apiId);
    }
    //展示日计划
    @PostMapping("/getSzTruckRailDayPlanList")
    @ApiOperation(value = "水渣日计划")
    public Map<String, Object> getSzTruckRailDayPlan(@RequestBody(required = false) Map<String, Object> mapValue,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSzTruckRailDayPlan(mapValue, pageNum, pageSize, apiId);
    }

    //新增钢材发往异地库计划
    @PostMapping("/addRailOffsetDayplan")
    public Map<String,Object> addRailOffsetDayplan(@RequestBody  Map<String, Object> mapVal){
        return amsFeign.addRailOffsetDayplan(mapVal);
    }
    //删除钢材发往异地库计划
    @PostMapping("/deleteRailOffsetDayplan/{dayPlanId}")
    public Map<String,Object> deleteRailOffsetDayplan(@PathVariable("dayPlanId") BigDecimal dayPlanId) {
        return amsFeign.deleteRailOffsetDayplan(dayPlanId);
    }
    //修改钢材发往异地库计划
    @PostMapping("/updateRailOffsetDayplan")
    public Map<String,Object> updateRailOffsetDayplan(@RequestBody  Map<String, Object> mapVal){
        return amsFeign.updateRailOffsetDayplan(mapVal);
    }

    //展示钢材发往异地库计划
    @PostMapping("/getRailOffsetDayplan")
    @ApiOperation(value = "展示钢材发往异地库计划")
    public Map<String, Object> getRailOffsetDayplan(@RequestBody(required = false) Map<String, Object> mapValue,
                                              Integer pageNum,
                                              Integer pageSize,
                                              Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getRailOffsetDayplan(mapValue, pageNum, pageSize, apiId);
    }

    ////************************************内转物流***************************************************
    /**
     *新增运输计划
     */
    @PostMapping("/addTruckPlan")
    public Map<String,Object> addTruckPlan(@RequestBody  Map<String, Object> mapVal) {
        return amsFeign.addTruckPlan(mapVal);
    }
    //删除
    @PostMapping("/deleteTruckRequirement/{planId}")
    public Map<String,Object> deleteTruckPlan(@PathVariable("planId") BigDecimal planId) {
        return amsFeign.deleteTruckPlan(planId);
    }
    /**
     * 修改运输计划/下发运输计划/承运商接收运输计划
     */
    @PostMapping("/updateTruckPlan")
    public Map<String,Object> updateTruckPlan(@RequestBody  Map<String, Object> mapVal){
        return amsFeign.updateTruckPlan(mapVal);
    }
    /**
     * 展示运输计划
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示运输计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "还未知", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getTruckPlanList")
    public Map<String, Object> getTruckPlanList(@RequestBody(required = false) Map<String,Object> mapValue,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getTruckPlanList(mapValue, pageNum, pageSize, apiId);
    }
    /**
     *用车单位提出需求
     *新增用车需求
     */
    @PostMapping("/addTruckRequirement")
    public Map<String,Object> addTruckRequirement(@RequestBody  Map<String, Object> mapVal) {
        return amsFeign.addTruckRequirement(mapVal);
    }
    //删除用车需求
    @PostMapping("/deleteTruckRequirement/{requirementId}")
    public Map<String,Object> deleteTruckRequirement(@PathVariable("requirementId") BigDecimal requirementId) {
        return amsFeign.deleteTruckRequirement(requirementId);
    }
    /**
     * 修改用车需求/下发用车需求
     */
    @PostMapping("/updateTruckRequirement")
    public Map<String,Object> updateTruckRequirement(@RequestBody  Map<String, Object> mapVal){
        return amsFeign.updateTruckRequirement(mapVal);
    }

    /**
     * 展示用车需求
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示用车需求")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "还未知", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getTruckRequirementList")
    public Map<String, Object> getTruckRequirementList(@RequestBody(required = false) Map<String,Object> mapValue,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getTruckRequirementList(mapValue, pageNum, pageSize, apiId);
    }
}
