package com.steerinfo.dil.feign;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/23 8:46
 * @Version:V2.0
 */
@FeignClient(value = "DIL-AMS-API-DEV", url = "${openfeign.AmsFeign.url}")
public interface AmsFeign {

    /**
     * 展示违约规则
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractbreach/getBreachList")
    Map<String, Object> getBreachList(@RequestBody(required = false) Map<String, Object> mapValue,
                                @RequestParam("pageNum") Integer pageNum,
                                @RequestParam("pageSize") Integer pageSize,
                                @RequestParam("apiId") Integer apiId);

    /**
     * 新增违约规则
     *
     * @param amsContractBreach
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractbreach/addContractBreach")
    Map<String, Object> addContractBreach(@RequestBody Map<String, Object> amsContractBreach);

    /**
     * 逻辑删除违约规则
     *
     * @param breachId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractbreach/deleteContractBreach/{breachId}")
    Map<String, Object> deleteContractBreach(@PathVariable("breachId") BigDecimal breachId);

    /**
     * 通过违约id查询
     *
     * @param breachId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractbreach/selectBreachToUpdate/{breachId}")
    Map<String, Object> selectBreachToUpdate(@PathVariable("breachId") BigDecimal breachId);

    /**
     * 修改违约规则
     *
     * @param amsContractBreach
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractbreach/updateContractBreach")
    Map<String, Object> updateContractBreach(@RequestBody Map<String, Object> amsContractBreach);

    /**
     * 展示港口装卸单价列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractotherprices/getLoadUnloadPriceList")
    Map<String, Object> getLoadUnloadPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                         @RequestParam Integer pageNum,
                                         @RequestParam Integer pageSize,
                                         @RequestParam Integer apiId);

    /**
     * 新增港口装卸单价
     *
     * @param amsContractOtherPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractotherprices/addLoadUnloadPrice")
    Map<String, Object> addLoadUnloadPrice(@RequestBody Map<String, Object> amsContractOtherPrice);

    /**
     * 逻辑删除港口装卸单价
     *
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractotherprices/deleteLoadUnloadPrice/{priceId}")
    Map<String, Object> deleteLoadUnloadPrice(@PathVariable("priceId") BigDecimal priceId);

    /**
     * 通过单价id查询
     *
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractotherprices/selectLoadUnloadPriceToUpdate/{priceId}")
    Map<String, Object> selectLoadUnloadPriceToUpdate(@PathVariable("priceId") BigDecimal priceId);

    /**
     * 修改港口装卸单价
     *
     * @param amsContractOtherPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontractotherprices/updateLoadUnloadPrice")
    Map<String, Object> updateLoadUnloadPrice(@RequestBody Map<String, Object> amsContractOtherPrice);


    /**
     * 展示火运单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttrainprices/getTrainPriceList")
    Map<String, Object> getTrainPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                    @RequestParam Integer pageNum,
                                    @RequestParam Integer pageSize,
                                    @RequestParam Integer apiId);

    /**
     * 新增火运单价
     *
     * @param amsContractTrainPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttrainprices/addTrainPrice")
    Map<String, Object> addTrainPrice(@RequestBody Map<String, Object> amsContractTrainPrice);

    /**
     * 逻辑删除火运单价
     *
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttrainprices/deleteTrainPrice/{priceId}")
    Map<String, Object> deleteTrainPrice(@PathVariable("priceId") BigDecimal priceId);

    /**
     * 通过单价id查询
     *
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttrainprices/selectTrainPriceToUpdate/{priceId}")
    Map<String, Object> selectTrainPriceToUpdate(@PathVariable("priceId") BigDecimal priceId);

    /**
     * 修改火运单价
     *
     * @param amsContractTrainPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttrainprices/updateTrainPrice")
    Map<String, Object> updateTrainPrice(@RequestBody Map<String, Object> amsContractTrainPrice);


    /**
     * 展示水运单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/getShipPriceList")
    Map<String, Object> getShipPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                   @RequestParam Integer pageNum,
                                   @RequestParam Integer pageSize,
                                   @RequestParam Integer apiId);

    /**
     * 新增水运单价
     *
     * @param amsContractTransportPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/addShipPrice")
    Map<String, Object> addShipPrice(@RequestBody Map<String, Object> amsContractTransportPrice);

    /**
     * 逻辑删除运费单价
     *
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/deleteShipPrice/{priceId}")
    Map<String, Object> deleteShipPrice(@PathVariable("priceId") BigDecimal priceId);

    /**
     * 修改水运单价
     *
     * @param amsContractTransportPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/updateShipPrice")
    Map<String, Object> updateShipPrice(@RequestBody Map<String, Object> amsContractTransportPrice);

    /**
     * 通过单价id查询
     *
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/selectPriceToUpdate/{priceId}")
    Map<String, Object> selectPriceToUpdate(@PathVariable("priceId") BigDecimal priceId);

    /**
     * 展示汽运单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/getTruckPriceList")
    Map<String, Object> getTruckPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                    @RequestParam Integer pageNum,
                                    @RequestParam Integer pageSize,
                                    @RequestParam Integer apiId);

    /**
     * 新增汽运单价
     *
     * @param amsContractTransportPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/addAmsContractTransportPrice")
    Map<String, Object> addAmsContractTransportPrice(@RequestBody Map<String, Object> amsContractTransportPrice);

    /**
     * 修改汽运单价
     *
     * @param amsContractTransportPrice
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/updateAmsContractTransportPrice")
    Map<String, Object> updateAmsContractTransportPrice(@RequestBody Map<String, Object> amsContractTransportPrice);

    /**
//     * 油价联动导致运价变动，批量修改运价
//     *
//     * @return
//     */
//    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/batchUpdateTransportPriceByOilPrice")
//    Map<String, Object> batchUpdateTransportPriceByOilPrice();

    /**
     * 展示采购订单列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amspurchaseorders/getPurchaseOrderList")
    Map<String, Object> getPurchaseOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                       @RequestParam Integer pageNum,
                                       @RequestParam Integer pageSize,
                                       @RequestParam Integer apiId);

    /**
     * 下拉框
     * @return
     */
    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getAddressDeliveryAddress")
    Map<String, Object> getAddressDeliveryAddress();

    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getShipperId")
    Map<String, Object> getShipperId();

    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getCarrierId")
    Map<String, Object> getCarrierId();

    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getCapacityId")
    Map<String, Object> getCapacityId();

    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getMaterialId")
    Map<String, Object> getMaterialId();

    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getTruckCapacityId")
    Map<String, Object> getTruckCapacityId();

    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getLineId")
    Map<String, Object> getLineId();
// ----------------------------------------------销售合同-------------------------------------
    /**
     * 销售合同查询汽运单价
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="查询汽运单价信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(109)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping(value = "/api/v1/saleContract/amscontracttransportprices/getAmsContractTransportPrice")
    Map<String, Object> amscontracttransportprices(@RequestBody(required = false) Map<String, Object> mapValue,
                                       @RequestParam Integer pageNum,
                                       @RequestParam Integer pageSize,
                                       @RequestParam Integer apiId);
    /**
     *销售合同新增汽运单价
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/addAmsContractTransportUnitPrice")
    Map<String, Object> addAmsContractTransportUnitPrice(@RequestBody(required = false) Map<String, Object> mapVal);

    /**
     *通过主键id删除汽运单价
     * @param priceId
     * @return
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/deleteAmsContractTransportPrice")
    Map<String, Object> deleteAmsContractTransportPrice(BigDecimal priceId);
    /**
     *通过主键渲染信息
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/getAmsContractTransportPriceByPriceId/{priceId}")
    Map<String, Object> getAmsContractTransportPriceByPriceId(@PathVariable("priceId") BigDecimal priceId);
    /**
     * 通过主键修改汽运单价
     */
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/updateAmsContractTransportUnitPrice")
    Map<String, Object> updateAmsContractTransportUnitPrice(@RequestBody(required = false) Map<String, Object> mapVal);
    /**
     * 油价联动导致运价变动，批量修改运价
     * @param
     * @return
     */
    @ApiOperation(value="油价联动导致运价变动，批量修改运价")
    @ApiImplicitParams({
    })
    @PostMapping(value = "/api/v1/ams/amscontracttransportprice/batchUpdateTransportPriceByOilPrice")
    Map<String, Object> batchUpdateTransportPriceByOilPrice(@RequestBody(required = false) Map<String, Object> mapVal);
    /**
     * 获取线路编号
     * @param
     * @return
     */
    @ApiOperation(value="获取线路编号")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getLineNo")
    Map<String, Object> getLineNo();
    /**
     * 获取线路编号
     * @param
     * @return
     */
    @ApiOperation(value="获取运力编号")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getCapacityNumber")
    Map<String, Object> getCapacityNumber();
    /**
     * 获取收货地址
     * @param
     * @return
     */
    @ApiOperation(value="获取收货地址")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/api/v1/ams/amscontracttransportprice/getDeliveryAddress")
    Map<String, Object> getDeliveryAddress();
    /**
     * 新增(固定派单/公开抢单)
     * @param mapVal
     * @return
     */
    @ApiOperation(value="新增(固定派单/公开抢单)")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsDispatchSaleOrder", value = "(固定派单/公开抢单)对象", required = false, dataType = "AmsDispatchSaleOrder")
    })
    @PostMapping(value = "/api/v1/ams/amsdispatchsaleorders/addAmsDispatchSaleOrder")
    Map<String, Object> addAmsDispatchSaleOrder(@RequestBody(required = false) Map<String, Object> mapVal);
    /**
     * 获取收货地址
     * @param
     * @return
     */
    @ApiOperation(value="获取收货地址")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/api/v1/ams/amsdispatchsaleorders/getCarrierName")
    Map<String, Object> getCarrierName();

    /**
     * 查询未上报销售订单信息
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="查询未上报销售订单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(98)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping("/api/v1/ams/amssaleorders/getSaleOrderInfo")
    Map<String, Object> getSaleOrderInfo(@RequestBody(required = false) Map<String, Object> mapValue,
                                             @RequestParam Integer pageNum,
                                             @RequestParam Integer pageSize,
                                             @RequestParam Integer apiId);
    /**
     * 查询已上报销售订单信息
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="查询已上报销售订单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(98)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping("/api/v1/ams/amssaleorders/getSaleOrderReported")
    Map<String, Object> getSaleOrderReported(@RequestBody(required = false) Map<String, Object> mapValue,
                                   @RequestParam Integer pageNum,
                                   @RequestParam Integer pageSize,
                                   @RequestParam Integer apiId);

    /**
     * 查询财务已审批销售订单信息
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="查询财务已审批销售订单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(105)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping("/api/v1/ams/amssaleorders/getAmsSaleOrderApproved")
    Map<String, Object> getAmsSaleOrderApproved(@RequestBody(required = false) Map<String, Object> mapValue,
                                       @RequestParam Integer pageNum,
                                       @RequestParam Integer pageSize,
                                       @RequestParam Integer apiId);

    /**
     * 根据销售订单号查询销售订单详细信息
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */

    @ApiOperation(value="根据销售订单号查询销售订单详细信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(100)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping("/api/v1/ams/amssaleorders/getSaleOrderDetail")
    Map<String, Object> getSaleOrderDetail(@RequestBody(required = false) Map<String, Object> mapValue,
                                          @RequestParam Integer pageNum,
                                          @RequestParam Integer pageSize,
                                          @RequestParam Integer apiId);
    /**
     * 上传销售订单
     * @param saleOrderId
     * @return
     */
    @ApiOperation(value="上传销售订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "saleOrderId", value = "销售订单ID", required = false, dataType = "java.math.BigDecimal")
    })
    @PostMapping(value = "/api/v1/ams/amssaleorders/uploadSaleOrder/{saleOrderId}")
    Map<String, Object> uploadSaleOrder(@PathVariable("saleOrderId") BigDecimal saleOrderId);
    /**
     * 新增销售订单
     */
    @ApiOperation(value="新增销售订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsSaleOrder", value = "销售订单对象", required = false, dataType = "AmsSaleOrder")
    })
    @PostMapping(value = "/api/v1/ams/amssaleorders/addAmsSaleOrder")
    Map<String, Object> addAmsSaleOrder(@RequestBody(required = false) Map<String,Object> map);

    /**
     * 通过主键渲染销售订单信息
     * @param saleOrderId
     * @return
     */
    @ApiOperation(value="通过主键渲染销售订单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "saleOrderId", value = "主键Id", required = false, dataType = "java.math.BigDecimal")
    })
    @PostMapping(value = "/api/v1/ams/amssaleorders/getAmsSaleOrderBySaleOrderId/{saleOrderId}")
    Map<String, Object> getAmsSaleOrderBySaleOrderId(@PathVariable("saleOrderId") BigDecimal saleOrderId);
    /**
     * 通过主键修改销售订单
     * @param map
     * @return
     */
    @ApiOperation(value="通过主键修改销售订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsSaleOrder", value = "销售订单对象", required = false, dataType = "AmsSaleOrder")
    })
    @PostMapping(value = "/api/v1/ams/amssaleorders/updateAmsSaleOrder")
    Map<String, Object> updateAmsSaleOrder(@RequestBody(required = false) Map<String,Object> map);
    /**
     * 通过主键删除销售订单
     * @param saleOrderId
     * @return
     */
    @ApiOperation(value="通过主键删除销售订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "saleOrderId", value = "主键Id", required = false, dataType = "java.math.BigDecimal")
    })
    @PostMapping(value = "/api/v1/ams/amssaleorders/deleteAmsSaleOrderBySaleOrderId")
    Map<String, Object> deleteAmsSaleOrderBySaleOrderId(BigDecimal saleOrderId);
    @ApiOperation(value="根据销售订单号查询销售订单修改日志")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(100)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping(value = "/api/v1/ams/amssaleorders/getSaleOrderUpdateLog")
    Map<String, Object> getSaleOrderUpdateLog(@RequestBody(required = false) Map<String, Object> mapValue,
                                     @RequestParam Integer pageNum,
                                     @RequestParam Integer pageSize,
                                     @RequestParam Integer apiId);
    /**
     * 获取发货单位
     */
    @ApiOperation(value="获取发货单位")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/api/v1/ams/amssaleorders/getShipperName")
    Map<String, Object> getShipperName();
    /**
     * 获取收货单位
     */
    @ApiOperation(value="获取收货单位")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/api/v1/ams/amssaleorders/getConsigneeCompanyName")
    Map<String, Object> getConsigneeCompanyName();
    /**
     * 新增销售订单物资信息
     * @param map
     * @return
     */
    @ApiOperation(value="新增销售订单物资信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsSaleOrderMaterial", value = "销售订单物资信息对象", required = false, dataType = "AmsSaleOrderMaterial")
    })
    @PostMapping(value = "/api/v1/ams/amssaleordermaterials/addAmsSaleOrderMaterial")
    Map<String, Object> addAmsSaleOrderMaterial(@RequestBody(required = false) Map<String,Object> map);

    /**
     *通过主键渲染销售订单物资信息
     * @param saleOrderMaterialId
     * @return
     */
    @ApiOperation(value="通过主键渲染销售订单物资信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsSaleOrderMaterial", value = "销售订单物资信息对象", required = false, dataType = "AmsSaleOrderMaterial")
    })
    @PostMapping(value = "/api/v1/ams/amssaleordermaterials/getAmsSaleOrderMaterialBySaleOrderMaterialId/{saleOrderMaterialId}")
    Map<String, Object> getAmsSaleOrderMaterialBySaleOrderMaterialId(@PathVariable("saleOrderMaterialId") BigDecimal saleOrderMaterialId);
    /**
     * 通过主键删除销售订单物资信息
     * @param saleOrderMaterialId
     * @return
     */
    @ApiOperation(value="通过主键删除销售订单物资信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "saleOrderMaterialId", value = "主键Id", required = false, dataType = "java.math.BigDecimal")
    })
    @PostMapping(value = "/api/v1/ams/amssaleordermaterials/deleteAmsSaleOrderMaterialBySaleOrderMaterialId")
    Map<String, Object> deleteAmsSaleOrderMaterialBySaleOrderMaterialId(BigDecimal saleOrderMaterialId);

    /**
     * 通过主键获取收货地址
     * @param saleOrderMaterialId
     * @return
     */
    @ApiOperation(value="通过主键获取收货地址")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "saleOrderMaterialId", value = "主键Id", required = false, dataType = "java.math.BigDecimal")
    })
    @PostMapping(value = "/api/v1/ams/amssaleordermaterials/getAddress/{saleOrderMaterialId}")
    Map<String, Object> getAddress(BigDecimal saleOrderMaterialId);


    /**
     * 通过主键修改销售订单信息(新增一条），过去的成为历史记录
     * @param map
     * @return
     */
    @ApiOperation(value="通过主键修改销售订单信息(新增一条），过去的成为历史记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsSaleOrderMaterial", value = "销售订单物资信息对象", required = false, dataType = "AmsSaleOrderMaterial")
    })
    @PostMapping(value = "/api/v1/ams/amssaleordermaterials/updateAddress")
    Map<String, Object> updateAddress(@RequestBody(required = false)Map<String,Object> map);

    /**
     * 查询销售计划信息
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="查询销售计划信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(92)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping(value = "/api/v1/ams/amssaleplans/getSalePlanInfo")
    Map<String, Object> getSalePlanInfo(@RequestBody(required = false) Map<String, Object> mapValue,
                                        @RequestParam Integer pageNum,
                                        @RequestParam Integer pageSize,
                                        @RequestParam Integer apiId);

    /**
     * 新增销售计划
     * @param map
     * @return
     */
    @ApiOperation(value="新增销售计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amssaleplans", value = "主键Id", required = false, dataType = "java.math.BigDecimal")
    })
    @PostMapping(value = "/api/v1/ams/amssaleplans/addAmsSalePlan")
    Map<String, Object> addAmsSalePlan(@RequestBody(required = false)Map<String,Object> map);

    /**
     * 通过主键查询销售计划信息
     * @param planId
     * @return
     */
    @ApiOperation(value="通过主键查询销售计划信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "销售计划主键", required = false, dataType = "BigDecimal")
    })
    @PostMapping(value = "/api/v1/ams/amssaleplans/getAmsSalePlanByPlanId/{planId}")
    Map<String, Object> getAmsSalePlanByPlanId(@PathVariable("planId") BigDecimal planId);
    /**
     * 通过主键修改销售计划
     * @param map
     * @return
     */
    @ApiOperation(value="通过主键修改车皮装车作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsSalePlan", value = "修改车皮装车map", required = false, dataType = "AmsSalePlan")
    })
    @PostMapping(value = "/api/v1/ams/amssaleplans/upadteAmsSalePlanByPlanId")
    Map<String, Object> upadteAmsSalePlanByPlanId(@RequestBody(required = false)Map<String,Object> map);
    /**
     * 通过主键删除销售计划
     * @param planId
     * @return
     */
    @ApiOperation(value="通过主键删除车皮装车作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "主键ID", required = false, dataType = "BigDecimal")
    })
    @PostMapping(value = "/api/v1/ams/amssaleplans/deleteAmsSalePlanByPlanId")
    Map<String, Object> deleteAmsSalePlanByPlanId(@RequestParam BigDecimal planId);

    /**
     * 获取规格型号
     * @param
     * @return
     */
    @ApiOperation(value="获取规格型号")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/api/v1/ams/amssaleplans/getMaterialName")
    Map<String, Object> getMaterialName();

    /**
     * 获取销售片区名称
     * @param
     * @return
     */
    @ApiOperation(value="获取销售片区名称")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/api/v1/ams/amssaleplans/getAreaName")
    Map<String, Object> getAreaName();

    /*
       AmstruckPurplanController中所有接口
    */
    @PostMapping("api/v1/ams/amstruckpurplans/getAllPurPlan")
    Map<String, Object> getAllPurPlan(@RequestBody(required=false) Map<String,Object> mapValue,
                                @RequestParam("apiId") Integer apiId,
                                @RequestParam("pageNum") Integer pageNum,
                                @RequestParam("pageSize") Integer pageSize,
                                @RequestParam("status") Integer status,
                                @RequestParam("con") String con);

    @PostMapping ("api/v1/ams/amstruckpurplans/getPurPlanById/{planId}")
    public Map<String, Object> getPurPlanById(@PathVariable("planId")Integer planId);

    @PostMapping("api/v1/ams/amstruckpurplans/addPurPlan")
    public Map<String, Object> addPurPlan(@RequestBody Map<String, Object> map);

    @PostMapping("api/v1/ams/amstruckpurplans/sendPurPlan/{planId}")
    public Map<String, Object> sendPurPlan(@PathVariable("planId")Integer planId);

    @PostMapping("api/v1/ams/amstruckpurplans/receptionPurPlan/{planId}")
    public Map<String, Object> receptionPurPlan(@PathVariable("planId")Integer planId);
    
    @PostMapping("api/v1/ams/amstruckpurplans/updatePurPlan")
    public Map<String, Object> updatePurPlan(@RequestBody Map<String, Object> amstruckPurplan);

    @PostMapping("api/v1/ams/amstruckpurplans/deletePurPlan/{planId}")
    public Map<String, Object> deletePurPlan(@PathVariable("planId")Integer planId);

    @PostMapping("api/v1/ams/amstruckpurplans/getDecomposedPlan")
    public Map<String, Object> getDecomposedPlan(@RequestBody(required=false) Map<String,Object> mapValue,
                                           @RequestParam("apiId") Integer apiId,
                                           @RequestParam("pageNum") Integer pageNum,
                                           @RequestParam("pageSize") Integer pageSize,
                                           @RequestParam("planId") Integer planId,
                                           @RequestParam("status") Integer status,
                                           @RequestParam("con") String con
    );

    //*****************************************内转物流**************************************
    //查询汽运单价
    @PostMapping(value = "/api/v1/ams/amscontracttransportprices/getAmsContractTransportPriceForConverted")
    Map<String,Object> getAmsContractTransportPriceForConverted(@RequestParam("lineId")BigDecimal lineId,
                                                                @RequestParam("apiId")Integer apiId,
                                                                @RequestParam("pageNum")Integer pageNum,
                                                                @RequestParam("pageSize")Integer pageSize);
    //获得运输线路
    @GetMapping(value = "/api/v1/ams/amscontracttransportprices/getLineRoute")
    Map<String,Object> getLineRoute();


    /**
     *展示销售公司已审核销售订单的车序号列表
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiOperation(value="查询销售公司已审核销售订单的车序号")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(181)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping(value = "/api/v1/ams/amssaleorders/getSaleOrderList")
    Map<String,Object> amsSaleOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                   @RequestParam Integer pageNum,
                                   @RequestParam Integer pageSize,
                                   @RequestParam Integer apiId);

    //固定派单：通过车序号查询收货地址，截取收货地址的区域，去资源管理中查询对应的承运商,将车序号与承运商绑定
    @PostMapping(value = "/api/v1/ams/amssaleorders/addAmsDispatchSaleOrder")
    Map<String,Object> addFixedAmsDispatchSaleOrder(@RequestBody(required = false) List<Map<String,Object>> mapValue);

    //公开派单
    //查询未分派车辆的销售订单的车序号
    @ApiOperation(value="展示车序号列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(182)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping(value = "/api/v1/ams/amssaleorders/getAmsSaleOrderMaterial")
    Map<String,Object> getAmsSaleOrderMaterial(@RequestBody(required = false) Map<String, Object> mapValue,
                                          @RequestParam Integer pageNum,
                                          @RequestParam Integer pageSize,
                                          @RequestParam Integer apiId);
    //新增公开派单
    @PostMapping(value = "/api/v1/ams/amssaleorders/addOpenAmsDispatchSaleOrder/{saleOrderMaterialId}")
    Map<String,Object> addOpenAmsDispatchSaleOrder(@PathVariable("saleOrderMaterialId") BigDecimal saleOrderId);
    //删除公开派单
    @PostMapping(value = "/api/v1/ams/amssaleorders//deleteAmsDispatchSaleOrder/{dispatchId}")
    Map<String,Object> deleteAmsDispatchSaleOrder(@PathVariable("dispatchId")BigDecimal saleOrderId);

    //展示公开派单
    @ApiOperation(value="展示公开派单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(181)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping(value = "/api/v1/ams/amssaleorders/getOpenDispatchSaleOrder")
    Map<String,Object> getOpenDispatchSaleOrder(@RequestBody(required = false) Map<String, Object> mapValue,
                                           @RequestParam Integer pageNum,
                                           @RequestParam Integer pageSize,
                                           @RequestParam Integer apiId);
    //修改公开派单
    @PostMapping(value = "/api/v1/ams/amssaleorders/updateOpenDispatchSaleOrder")
    Map<String,Object> updateOpenDispatchSaleOrder(@RequestBody(required = false) Map<String, Object> mapVal);

    //新增日计划
    @PostMapping(value = "/api/v1/ams/amstruckraildayplans/addTruckRailDayPlan")
    Map<String,Object> addTruckRailDayPlan(@RequestBody(required = false) Map<String, Object> mapVal);
    //删除日计划
    @PostMapping(value = "/api/v1/ams/amstruckraildayplans/deleteTruckRailDayPlan/{dayPlanId}")
    Map<String,Object> deleteTruckRailDayPlan(@PathVariable("dayPlanId") BigDecimal dayPlanId);
    //修改日计划
    @PostMapping(value = "/api/v1/ams/amstruckraildayplans/updateTruckRailDayPlan")
    Map<String,Object> updateTruckRailDayPlan(@RequestBody(required = false) Map<String, Object> mapVal);
    //查询日计划
    @ApiOperation(value="展示焦炭日计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(183)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping(value = "/api/v1/ams/amstruckraildayplans/getTruckRailDayPlanList")
    Map<String, Object> getTruckRailDayPlan(@RequestBody(required = false) Map<String, Object> mapValue,
                                      @RequestParam Integer pageNum,
                                      @RequestParam Integer pageSize,
                                      @RequestParam Integer apiId);
    //查询日计划
    @ApiOperation(value="展示水渣日计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(183)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping(value = "/api/v1/ams/amstruckraildayplans/getSzTruckRailDayPlanList")
    Map<String, Object> getSzTruckRailDayPlan(@RequestBody(required = false) Map<String, Object> mapValue,
                                        @RequestParam Integer pageNum,
                                        @RequestParam Integer pageSize,
                                        @RequestParam Integer apiId);

    //新增钢材发往异地库日计划
    @PostMapping(value = "/api/v1/ams/amsrailoffsetdayplan/addRailOffsetDayplan")
    Map<String,Object> addRailOffsetDayplan(@RequestBody(required = false) Map<String, Object> mapVal);

    //删除钢材发往异地库计划
    @PostMapping(value = "/api/v1/ams/amsrailoffsetdayplan/deleteRailOffsetDayplan/{dayPlanId}")
    Map<String,Object> deleteRailOffsetDayplan(@PathVariable("dayPlanId") BigDecimal dayPlanId);

    //修改钢材发往异地库计划
    @PostMapping(value = "/api/v1/ams/amsrailoffsetdayplan/addRailOffsetDayplan")
    Map<String,Object> updateRailOffsetDayplan(@RequestBody(required = false) Map<String, Object> mapVal);

    //展示钢材发往异地库计划
    @ApiOperation(value="展示钢材发往异地库计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(183)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping(value = "/api/v1/ams/amsrailoffsetdayplan/getRailOffsetDayplan")
    Map<String, Object> getRailOffsetDayplan(@RequestBody(required = false) Map<String, Object> mapValue,
                                       @RequestParam Integer pageNum,
                                       @RequestParam Integer pageSize,
                                       @RequestParam Integer apiId);

    /**
     *新增运输计划
     */
    @PostMapping(value = "/api/v1/ams/amstruckinwardplan/addTruckPlan")
    Map<String,Object> addTruckPlan(@RequestBody(required = false) Map<String, Object> mapVal);
    //删除运输计划
    @PostMapping(value = "/api/v1/ams/amstruckinwardplan/deleteTruckRequirement/{planId}")
    Map<String,Object> deleteTruckPlan(@PathVariable("planId") BigDecimal planId);
    //修改运输计划/下发运输计划/承运商接收运输计划
    @PostMapping(value = "/api/v1/ams/amstruckinwardplan/updateTruckPlan")
    Map<String,Object> updateTruckPlan(@RequestBody(required = false) Map<String, Object> mapVal);
    /**
     * 展示运输计划
     */
    @ApiOperation(value="展示运输计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(还没有设置表头)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping(value = "/api/v1/ams/amstruckinwardplan/getTruckPlanList")
    Map<String, Object> getTruckPlanList(@RequestBody(required = false) Map<String, Object> mapValue,
                                       @RequestParam Integer pageNum,
                                       @RequestParam Integer pageSize,
                                       @RequestParam Integer apiId);
    /**
     *新增用车需求
     */
    @PostMapping(value = "/api/v1/ams/amstruckinwardrequirement/addTruckRequirement")
    Map<String,Object> addTruckRequirement(@RequestBody(required = false) Map<String, Object> mapVal);
    //用车需求
    @PostMapping(value = "/api/v1/ams/amstruckinwardrequirement/deleteTruckRequirement/{requirementId}")
    Map<String,Object> deleteTruckRequirement(@PathVariable("requirementId") BigDecimal requirementId);
    //修改用车需求/下发用车需求
    @PostMapping(value = "/api/v1/ams/amstruckinwardrequirement/updateTruckRequirement")
    Map<String,Object> updateTruckRequirement(@RequestBody(required = false) Map<String, Object> mapVal);
    /**
     * 展示用车需求
     */
    @ApiOperation(value="展示用车需求")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(还没有设置表头)", value = "表头", required = false, dataType = "Interger")
    })
    @PostMapping(value = "/api/v1/ams/amstruckinwardrequirement/getTruckRequirementList")
    Map<String, Object> getTruckRequirementList(@RequestBody(required = false) Map<String, Object> mapValue,
                                   @RequestParam Integer pageNum,
                                   @RequestParam Integer pageSize,
                                   @RequestParam Integer apiId);

}